@@ -1,4 +1,4 @@
-from geodesign.experimentaldesign import latin_design
+from geodesign.experimentaldesign import check_topology
 from geodesign.experimentaldesign import select_geoms
 from geodesign.experimentaldesign import rotate_plot
 from geodesign.experimentaldesign import composite_union
\ No newline at end of file
