@@ -197,7 +197,7 @@ class composite_union:
             self.geodesign = unary_data
             if self.geodesign.crs == None:
                 self.geodesign.crs = data.crs
-            self.centroid = self.geodesign.centroid
+            self.centroid = self.unary_data.centroid
             
         elif data.crs == {'init': 'epsg: 3857'} and buffer == None:
             unary_data = gpd.GeoDataFrame(
@@ -207,7 +207,7 @@ class composite_union:
             self.geodesign = unary_data
             if self.geodesign.crs == None:
                 self.geodesign.crs = data.crs
-            self.centroid = self.geodesign.centroid
+            self.centroid = self.unary_data.centroid
             
         elif buffer is not None and data.crs != None:
             unary_data = gpd.GeoDataFrame(
@@ -217,7 +217,7 @@ class composite_union:
             self.geodesign = unary_data
             if self.geodesign.crs == None:
                 self.geodesign.crs = data.crs
-            self.centroid = self.geodesign.centroid
+            self.centroid = self.unary_data.centroid
             
         elif buffer is not None and data.crs == None:
             data.crs = {'init': 'epsg:4326'}
@@ -228,7 +228,7 @@ class composite_union:
             self.geodesign = unary_data
             if self.geodesign.crs == None:
                 self.geodesign.crs = data.crs
-            self.centroid = self.geodesign.centroid
+            self.centroid = self.unary_data.centroid
             
         else:
             self.geodesign = gpd.GeoDataFrame(geometry=gpd.GeoSeries(Polygon(unary_union(data.geometry).exterior.coords[:])))
